@@ -8,8 +8,13 @@ utils::globalVariables(c('ps','y'))
 #' @param treatment the treatment varaible as a logical type.
 #' @param percentPoints.treat the percentage of treatment points to randomly plot.
 #' @param percentPoints.control the percentage of control points to randomly plot.
+#' @param points.treat.alpha the transparency level for treatment points.
+#' @param points.control.alpha the transparency level for control points.
 #' @param responseTitle the label to use for the y-axis (i.e. the name of the response variable)
 #' @param treatmentTitle the label to use for the treatment legend.
+#' @param plot.strata an integer value greater than 2 indicating the number of vertical lines to 
+#'        plot corresponding to quantiles.
+#' @param plot.strata.alpha the alpha level for the vertical lines.
 #' @param ... other parameters passed to \code{\link{geom_smooth}} and
 #'        \code{\link{stat_smooth}}.
 #' @return a ggplot2 figure
@@ -37,19 +42,37 @@ loess.plot <- function(x, response, treatment,
 					   treatmentTitle='Treatment',
 					   percentPoints.treat=.1, 
 					   percentPoints.control=.01, 
+					   points.treat.alpha=.1,
+					   points.control.alpha=.1,
+					   plot.strata,
+					   plot.strata.alpha=.2,
 					   ...) {
 	df = data.frame(ps=x, response=response, treatment=treatment)
-	df.points.treat = df
-	df.points.control =  df
+	df.points.treat <- df[treatment,]
+	df.points.control <-  df[!treatment,]
+	df.points.treat <- df.points.treat[sample(nrow(df.points.treat), 
+											  nrow(df.points.treat) * percentPoints.treat),]
+	df.points.control <- df.points.control[sample(nrow(df.points.control),
+											      nrow(df.points.control) * percentPoints.control),]
 	pmain = ggplot(df, aes(x=ps, y=response, colour=treatment))
-	pmain = pmain + geom_point(data=df.points.control, 
-							   aes(x=ps, y=response, colour=treatment), alpha=.2)
-	pmain = pmain + geom_point(data=df.points.treat, 
-							   aes(x=ps, y=response, colour=treatment), alpha=.2)
+	if(nrow(df.points.control) > 0) {
+		pmain = pmain + geom_point(data=df.points.control, 
+								   aes(x=ps, y=response, colour=treatment), alpha=points.control.alpha)
+	}
+	if(nrow(df.points.treat) > 0) {
+		pmain = pmain + geom_point(data=df.points.treat, 
+								   aes(x=ps, y=response, colour=treatment), alpha=points.treat.alpha)
+	}
 	pmain = pmain + geom_smooth(...) + ylab(responseTitle) + xlab("Propensity Score") + 
 				theme(legend.position='none', legend.justification='left') + 
 				scale_colour_hue(treatmentTitle) + 
 				xlim(range(df$ps)) + ylim(range(df$response))
+	
+	if(!missing(plot.strata)) {
+		vlines <- quantile(df$ps, seq(0,1,1/plot.strata), na.rm=TRUE)
+		pmain <- pmain + geom_vline(xintercept=vlines, color='black', alpha=plot.strata.alpha)
+	}
+	
 	ptop = ggplot(df, aes(x=ps, colour=treatment, group=treatment)) + 
 				geom_density() + 
 				theme(legend.position='none') + 
@@ -83,7 +106,7 @@ loess.plot <- function(x, response, treatment,
 	grid_layout <- grid.layout(nrow=2, ncol=2, widths=c(3,1), heights=c(1,3))
 	grid.newpage()
 	pushViewport( viewport( layout=grid_layout ) )
-	multilevelPSA:::align.plots(grid_layout, 
+	align.plots(grid_layout, 
 								list(ptop, 1, 1), 
 								list(pmain, 2, 1), 
 								list(pright, 2, 2),
